# coding: utf-8

"""
    syntropy-controller

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class TsoaPartialUserAdminObject_(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "user_is_admin": "bool",
        "user_email": "str",
        "user_email_confirmed": "bool",
        "user_email_verification_code": "str",
        "user_password": "str",
        "user_account_deletion_code": "str",
        "user_password_reset_code": "str",
        "user_facebook_id": "str",
        "user_google_id": "str",
        "user_agreed_terms": "bool",
        "user_traceroute_enabled": "bool",
        "user_trial_until": "datetime",
        "user_phone_number": "str",
        "user_name": "str",
        "user_surname": "str",
        "user_company_name": "str",
        "user_timezone": "str",
        "user_settings": "UserSettings",
    }

    attribute_map = {
        "user_is_admin": "user_is_admin",
        "user_email": "user_email",
        "user_email_confirmed": "user_email_confirmed",
        "user_email_verification_code": "user_email_verification_code",
        "user_password": "user_password",
        "user_account_deletion_code": "user_account_deletion_code",
        "user_password_reset_code": "user_password_reset_code",
        "user_facebook_id": "user_facebook_id",
        "user_google_id": "user_google_id",
        "user_agreed_terms": "user_agreed_terms",
        "user_traceroute_enabled": "user_traceroute_enabled",
        "user_trial_until": "user_trial_until",
        "user_phone_number": "user_phone_number",
        "user_name": "user_name",
        "user_surname": "user_surname",
        "user_company_name": "user_company_name",
        "user_timezone": "user_timezone",
        "user_settings": "user_settings",
    }

    def __init__(
        self,
        user_is_admin=None,
        user_email=None,
        user_email_confirmed=None,
        user_email_verification_code=None,
        user_password=None,
        user_account_deletion_code=None,
        user_password_reset_code=None,
        user_facebook_id=None,
        user_google_id=None,
        user_agreed_terms=None,
        user_traceroute_enabled=None,
        user_trial_until=None,
        user_phone_number=None,
        user_name=None,
        user_surname=None,
        user_company_name=None,
        user_timezone=None,
        user_settings=None,
    ):  # noqa: E501
        """TsoaPartialUserAdminObject_ - a model defined in Swagger"""  # noqa: E501
        self._user_is_admin = None
        self._user_email = None
        self._user_email_confirmed = None
        self._user_email_verification_code = None
        self._user_password = None
        self._user_account_deletion_code = None
        self._user_password_reset_code = None
        self._user_facebook_id = None
        self._user_google_id = None
        self._user_agreed_terms = None
        self._user_traceroute_enabled = None
        self._user_trial_until = None
        self._user_phone_number = None
        self._user_name = None
        self._user_surname = None
        self._user_company_name = None
        self._user_timezone = None
        self._user_settings = None
        self.discriminator = None
        if user_is_admin is not None:
            self.user_is_admin = user_is_admin
        if user_email is not None:
            self.user_email = user_email
        if user_email_confirmed is not None:
            self.user_email_confirmed = user_email_confirmed
        if user_email_verification_code is not None:
            self.user_email_verification_code = user_email_verification_code
        if user_password is not None:
            self.user_password = user_password
        if user_account_deletion_code is not None:
            self.user_account_deletion_code = user_account_deletion_code
        if user_password_reset_code is not None:
            self.user_password_reset_code = user_password_reset_code
        if user_facebook_id is not None:
            self.user_facebook_id = user_facebook_id
        if user_google_id is not None:
            self.user_google_id = user_google_id
        if user_agreed_terms is not None:
            self.user_agreed_terms = user_agreed_terms
        if user_traceroute_enabled is not None:
            self.user_traceroute_enabled = user_traceroute_enabled
        if user_trial_until is not None:
            self.user_trial_until = user_trial_until
        if user_phone_number is not None:
            self.user_phone_number = user_phone_number
        if user_name is not None:
            self.user_name = user_name
        if user_surname is not None:
            self.user_surname = user_surname
        if user_company_name is not None:
            self.user_company_name = user_company_name
        if user_timezone is not None:
            self.user_timezone = user_timezone
        if user_settings is not None:
            self.user_settings = user_settings

    @property
    def user_is_admin(self):
        """Gets the user_is_admin of this TsoaPartialUserAdminObject_.  # noqa: E501


        :return: The user_is_admin of this TsoaPartialUserAdminObject_.  # noqa: E501
        :rtype: bool
        """
        return self._user_is_admin

    @user_is_admin.setter
    def user_is_admin(self, user_is_admin):
        """Sets the user_is_admin of this TsoaPartialUserAdminObject_.


        :param user_is_admin: The user_is_admin of this TsoaPartialUserAdminObject_.  # noqa: E501
        :type: bool
        """

        self._user_is_admin = user_is_admin

    @property
    def user_email(self):
        """Gets the user_email of this TsoaPartialUserAdminObject_.  # noqa: E501


        :return: The user_email of this TsoaPartialUserAdminObject_.  # noqa: E501
        :rtype: str
        """
        return self._user_email

    @user_email.setter
    def user_email(self, user_email):
        """Sets the user_email of this TsoaPartialUserAdminObject_.


        :param user_email: The user_email of this TsoaPartialUserAdminObject_.  # noqa: E501
        :type: str
        """

        self._user_email = user_email

    @property
    def user_email_confirmed(self):
        """Gets the user_email_confirmed of this TsoaPartialUserAdminObject_.  # noqa: E501


        :return: The user_email_confirmed of this TsoaPartialUserAdminObject_.  # noqa: E501
        :rtype: bool
        """
        return self._user_email_confirmed

    @user_email_confirmed.setter
    def user_email_confirmed(self, user_email_confirmed):
        """Sets the user_email_confirmed of this TsoaPartialUserAdminObject_.


        :param user_email_confirmed: The user_email_confirmed of this TsoaPartialUserAdminObject_.  # noqa: E501
        :type: bool
        """

        self._user_email_confirmed = user_email_confirmed

    @property
    def user_email_verification_code(self):
        """Gets the user_email_verification_code of this TsoaPartialUserAdminObject_.  # noqa: E501


        :return: The user_email_verification_code of this TsoaPartialUserAdminObject_.  # noqa: E501
        :rtype: str
        """
        return self._user_email_verification_code

    @user_email_verification_code.setter
    def user_email_verification_code(self, user_email_verification_code):
        """Sets the user_email_verification_code of this TsoaPartialUserAdminObject_.


        :param user_email_verification_code: The user_email_verification_code of this TsoaPartialUserAdminObject_.  # noqa: E501
        :type: str
        """

        self._user_email_verification_code = user_email_verification_code

    @property
    def user_password(self):
        """Gets the user_password of this TsoaPartialUserAdminObject_.  # noqa: E501


        :return: The user_password of this TsoaPartialUserAdminObject_.  # noqa: E501
        :rtype: str
        """
        return self._user_password

    @user_password.setter
    def user_password(self, user_password):
        """Sets the user_password of this TsoaPartialUserAdminObject_.


        :param user_password: The user_password of this TsoaPartialUserAdminObject_.  # noqa: E501
        :type: str
        """

        self._user_password = user_password

    @property
    def user_account_deletion_code(self):
        """Gets the user_account_deletion_code of this TsoaPartialUserAdminObject_.  # noqa: E501


        :return: The user_account_deletion_code of this TsoaPartialUserAdminObject_.  # noqa: E501
        :rtype: str
        """
        return self._user_account_deletion_code

    @user_account_deletion_code.setter
    def user_account_deletion_code(self, user_account_deletion_code):
        """Sets the user_account_deletion_code of this TsoaPartialUserAdminObject_.


        :param user_account_deletion_code: The user_account_deletion_code of this TsoaPartialUserAdminObject_.  # noqa: E501
        :type: str
        """

        self._user_account_deletion_code = user_account_deletion_code

    @property
    def user_password_reset_code(self):
        """Gets the user_password_reset_code of this TsoaPartialUserAdminObject_.  # noqa: E501


        :return: The user_password_reset_code of this TsoaPartialUserAdminObject_.  # noqa: E501
        :rtype: str
        """
        return self._user_password_reset_code

    @user_password_reset_code.setter
    def user_password_reset_code(self, user_password_reset_code):
        """Sets the user_password_reset_code of this TsoaPartialUserAdminObject_.


        :param user_password_reset_code: The user_password_reset_code of this TsoaPartialUserAdminObject_.  # noqa: E501
        :type: str
        """

        self._user_password_reset_code = user_password_reset_code

    @property
    def user_facebook_id(self):
        """Gets the user_facebook_id of this TsoaPartialUserAdminObject_.  # noqa: E501


        :return: The user_facebook_id of this TsoaPartialUserAdminObject_.  # noqa: E501
        :rtype: str
        """
        return self._user_facebook_id

    @user_facebook_id.setter
    def user_facebook_id(self, user_facebook_id):
        """Sets the user_facebook_id of this TsoaPartialUserAdminObject_.


        :param user_facebook_id: The user_facebook_id of this TsoaPartialUserAdminObject_.  # noqa: E501
        :type: str
        """

        self._user_facebook_id = user_facebook_id

    @property
    def user_google_id(self):
        """Gets the user_google_id of this TsoaPartialUserAdminObject_.  # noqa: E501


        :return: The user_google_id of this TsoaPartialUserAdminObject_.  # noqa: E501
        :rtype: str
        """
        return self._user_google_id

    @user_google_id.setter
    def user_google_id(self, user_google_id):
        """Sets the user_google_id of this TsoaPartialUserAdminObject_.


        :param user_google_id: The user_google_id of this TsoaPartialUserAdminObject_.  # noqa: E501
        :type: str
        """

        self._user_google_id = user_google_id

    @property
    def user_agreed_terms(self):
        """Gets the user_agreed_terms of this TsoaPartialUserAdminObject_.  # noqa: E501


        :return: The user_agreed_terms of this TsoaPartialUserAdminObject_.  # noqa: E501
        :rtype: bool
        """
        return self._user_agreed_terms

    @user_agreed_terms.setter
    def user_agreed_terms(self, user_agreed_terms):
        """Sets the user_agreed_terms of this TsoaPartialUserAdminObject_.


        :param user_agreed_terms: The user_agreed_terms of this TsoaPartialUserAdminObject_.  # noqa: E501
        :type: bool
        """

        self._user_agreed_terms = user_agreed_terms

    @property
    def user_traceroute_enabled(self):
        """Gets the user_traceroute_enabled of this TsoaPartialUserAdminObject_.  # noqa: E501


        :return: The user_traceroute_enabled of this TsoaPartialUserAdminObject_.  # noqa: E501
        :rtype: bool
        """
        return self._user_traceroute_enabled

    @user_traceroute_enabled.setter
    def user_traceroute_enabled(self, user_traceroute_enabled):
        """Sets the user_traceroute_enabled of this TsoaPartialUserAdminObject_.


        :param user_traceroute_enabled: The user_traceroute_enabled of this TsoaPartialUserAdminObject_.  # noqa: E501
        :type: bool
        """

        self._user_traceroute_enabled = user_traceroute_enabled

    @property
    def user_trial_until(self):
        """Gets the user_trial_until of this TsoaPartialUserAdminObject_.  # noqa: E501


        :return: The user_trial_until of this TsoaPartialUserAdminObject_.  # noqa: E501
        :rtype: datetime
        """
        return self._user_trial_until

    @user_trial_until.setter
    def user_trial_until(self, user_trial_until):
        """Sets the user_trial_until of this TsoaPartialUserAdminObject_.


        :param user_trial_until: The user_trial_until of this TsoaPartialUserAdminObject_.  # noqa: E501
        :type: datetime
        """

        self._user_trial_until = user_trial_until

    @property
    def user_phone_number(self):
        """Gets the user_phone_number of this TsoaPartialUserAdminObject_.  # noqa: E501


        :return: The user_phone_number of this TsoaPartialUserAdminObject_.  # noqa: E501
        :rtype: str
        """
        return self._user_phone_number

    @user_phone_number.setter
    def user_phone_number(self, user_phone_number):
        """Sets the user_phone_number of this TsoaPartialUserAdminObject_.


        :param user_phone_number: The user_phone_number of this TsoaPartialUserAdminObject_.  # noqa: E501
        :type: str
        """

        self._user_phone_number = user_phone_number

    @property
    def user_name(self):
        """Gets the user_name of this TsoaPartialUserAdminObject_.  # noqa: E501


        :return: The user_name of this TsoaPartialUserAdminObject_.  # noqa: E501
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this TsoaPartialUserAdminObject_.


        :param user_name: The user_name of this TsoaPartialUserAdminObject_.  # noqa: E501
        :type: str
        """

        self._user_name = user_name

    @property
    def user_surname(self):
        """Gets the user_surname of this TsoaPartialUserAdminObject_.  # noqa: E501


        :return: The user_surname of this TsoaPartialUserAdminObject_.  # noqa: E501
        :rtype: str
        """
        return self._user_surname

    @user_surname.setter
    def user_surname(self, user_surname):
        """Sets the user_surname of this TsoaPartialUserAdminObject_.


        :param user_surname: The user_surname of this TsoaPartialUserAdminObject_.  # noqa: E501
        :type: str
        """

        self._user_surname = user_surname

    @property
    def user_company_name(self):
        """Gets the user_company_name of this TsoaPartialUserAdminObject_.  # noqa: E501


        :return: The user_company_name of this TsoaPartialUserAdminObject_.  # noqa: E501
        :rtype: str
        """
        return self._user_company_name

    @user_company_name.setter
    def user_company_name(self, user_company_name):
        """Sets the user_company_name of this TsoaPartialUserAdminObject_.


        :param user_company_name: The user_company_name of this TsoaPartialUserAdminObject_.  # noqa: E501
        :type: str
        """

        self._user_company_name = user_company_name

    @property
    def user_timezone(self):
        """Gets the user_timezone of this TsoaPartialUserAdminObject_.  # noqa: E501


        :return: The user_timezone of this TsoaPartialUserAdminObject_.  # noqa: E501
        :rtype: str
        """
        return self._user_timezone

    @user_timezone.setter
    def user_timezone(self, user_timezone):
        """Sets the user_timezone of this TsoaPartialUserAdminObject_.


        :param user_timezone: The user_timezone of this TsoaPartialUserAdminObject_.  # noqa: E501
        :type: str
        """

        self._user_timezone = user_timezone

    @property
    def user_settings(self):
        """Gets the user_settings of this TsoaPartialUserAdminObject_.  # noqa: E501


        :return: The user_settings of this TsoaPartialUserAdminObject_.  # noqa: E501
        :rtype: UserSettings
        """
        return self._user_settings

    @user_settings.setter
    def user_settings(self, user_settings):
        """Sets the user_settings of this TsoaPartialUserAdminObject_.


        :param user_settings: The user_settings of this TsoaPartialUserAdminObject_.  # noqa: E501
        :type: UserSettings
        """

        self._user_settings = user_settings

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(TsoaPartialUserAdminObject_, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TsoaPartialUserAdminObject_):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
